@@ -3,7 +3,7 @@
 
 __all__ = ['Csv', 'Xls', 'Xlsx', 'guess_type']
 
-VERSION = (0, 2, 1)
+VERSION = (0, 2, 3)
 __version__ = ".".join(map(str, VERSION))
 
 class PyHeaderFile(object):
@@ -527,18 +527,25 @@ class Ods(PyHeaderSheet):
         # self.ezodf = ezodf
         raise NotImplementedError
 
-def guess_type(filename):
+def guess_type(filename,**kwargs):
     """ Utility function to call classes based on filename extension.
-    Just usefull if you are reading the file and don't know file extension.
+    Just usefull if you are reading the file and don't know file extension. You can pass kwargs and these args are passed to class only if they are used in class.
     """
     import os
 
     extension = os.path.splitext(filename)[1]
-    case = {'.xls': "Xls(filename)",
-            '.xlsx': "Xlsx(filename)",
-            '.csv': "Csv(filename)"}
-    if extension and case.get(extension):
-        return eval(case.get(extension.lower()))
+    case = {'.xls': Xls,
+            '.xlsx': Xlsx,
+            '.csv': Csv}
+    if extension and case.get(extension.lower()):
+        low_extension = extension.lower()
+        new_kwargs = dict()
+        class_name = case.get(low_extension)
+        class_kwargs = class_name.__init__.func_code.co_names
+        for kwarg in kwargs:
+            if kwarg in class_kwargs:
+                new_kwargs[kwarg] = kwargs[kwarg]
+        return case.get(low_extension)(filename, **new_kwargs)
     else:
         raise Exception('No extension found')
 
